from . import session
class APPOINTMENTS(object):

    def __init__(self, appointment_startdate=None, appointment_enddate=None, appointment_id=None, fake_count=1):
        self.appointment_startdate = appointment_startdate
        self.appointment_enddate = appointment_enddate
        self.appointment_id = appointment_id
        self.fake_count = fake_count

    @classmethod
    def appointment_list(cls, appointment_startdate=None, appointment_enddate=None):
        """
            Appointment startdate format: YYYY-MM-DD
            Appointment endate format: YYYY-MM-DD
        """
        path = 'https://drchrono.com/api/appointments?since={}'.format(appointment_startdate)
        list_response = []
        while path:
            data = session.get(path).json()
            list_response.extend(data['results'])
            path = data['next'] # A JSON null on the last page
        return list_response

    @classmethod
    def appointment_single(cls, appointment_id):
        path = 'https://drchrono.com/api/appointments/{}'.format(appointment_id)
        try: 
            data = session.get(path)
            data_json = data.json()
            return data_json
        except Exception as e:
            print(e)


import os
import requests
import json
from dotenv import load_dotenv

# import keys 
load_dotenv()

"""
documentation section: https://app.drchrono.com/api-docs/#section/Introduction 
"""

API_TOKEN = os.environ.get('DRCHRONO_API_TOKEN')
BASE_URL = "https://drchrono.com/api/"

### Initial a initial session 
session = requests.Session()
session.headers = {}
session.headers['Authorization'] = 'Bearer %s' % API_TOKEN

class APIKeyMissingError(Warning):
    pass

if not API_TOKEN:
    print("""All production methods require an API access token that is valid for 48 hours. 
        If you are planning on using the fake endpoints, 
        you can still use the package without an API key.
        """)

from .admin_doctors import DOCTORS
from .admin_users import USERS 
from .clinical_appointments import APPOINTMENTS
from .clinical_documents import DOCUMENTS
from .clinical_medications import MEDICATIONS
from .clinical_patients import PATIENTS
from .fake_data import FAKER



from . import session

class USERS(object):

    def __init__(self, user_id=None, group_id=None, fake_count=1):
        self.user_id = user_id
        self.group_id = group_id
        self.fake_count = fake_count

    @staticmethod
    def userlist():
        path = 'https://app.drchrono.com/api/users'
        list_response = []
        while path:
            data = session.get(path)
            data_json = data.json()
            list_response.extend(data_json['results'])
            path = data_json['next']
        return list_response

    @staticmethod
    def usergrouplist():
        path = 'https://app.drchrono.com/api/user_groups'
        list_response = []
        while path:
            data = session.get(path)
            data_json = data.json()
            list_response.extend(data_json['results'])
            path = data_json['next']
        return list_response

    @classmethod
    def user_single(cls, user_id):
        path = 'https://app.drchrono.com/api/users/{}'.format(user_id)
        try: 
            data = session.get(path)
            data_json = data.json()
            return data_json
        except Exception as e:
            print(e)

    @classmethod
    def usergrouplist_single(cls, group_id):
        path = 'https://app.drchrono.com/api/user_groups/{}'.format(group_id)
        try: 
            data = session.get(path)
            data_json = data.json()
            return data_json
        except Exception as e:
            print(e)






from faker import Faker
import datetime
import random

def patientlist_fake(fake_count, doc_ids):
    localeList = ['en-US']
    fake = Faker(localeList)
    list_response = []
    start_date = datetime.datetime.now() - datetime.timedelta(days=730)
    end_date = datetime.datetime.now() + datetime.timedelta(days=730)
    dob_startdate = datetime.datetime.now() - datetime.timedelta(days=365*70)
    dob_enddate = datetime.datetime.now() - datetime.timedelta(days=365*18)
    appnt_firstdate = datetime.datetime.now() - datetime.timedelta(days=365*2)
    appnt_firstenddate = datetime.datetime.now() - datetime.timedelta(days=365*1)
    appnt_lastdate = datetime.datetime.now() - datetime.timedelta(days=365*1)
    appnt_lastenddate = datetime.datetime.now() + datetime.timedelta(days=365*1)
    for i in range(fake_count):
        dictionaryResponse = {
            "address": fake.address(),
            "auto_accident_insurance": {
                "auto_accident_case_number": fake.ssn(),
                "auto_accident_claim_rep_address": fake.address(),
                "auto_accident_claim_rep_city": fake.city(),
                "auto_accident_claim_rep_is_insurer": fake.boolean(),
                "auto_accident_claim_rep_name": fake.name(),
                "auto_accident_claim_rep_state": fake.state(),
                "auto_accident_claim_rep_zip": fake.zipcode(),
                "auto_accident_company": fake.company(),
                "auto_accident_date_of_accident": fake.date_time_between(start_date=start_date, end_date=end_date).isoformat(),
                "auto_accident_disabled_from_date": fake.date_time_between(start_date=start_date, end_date=end_date).isoformat(),
                "auto_accident_disabled_to_date": fake.date_time_between(start_date=start_date, end_date=end_date).isoformat(),
                "auto_accident_had_similar_condition": fake.boolean(),
                "auto_accident_is_subscriber_the_patient": fake.boolean(),
                "auto_accident_notes": fake.text(),
                "auto_accident_patient_relationship_to_subscriber": fake.random_element(elements=('self', 'spouse', 'child', 'other')),
                "auto_accident_payer_address": fake.address(),
                "auto_accident_payer_city": fake.city(),
                "auto_accident_payer_id": fake.ssn(),
                "auto_accident_payer_state": fake.state(),
                "auto_accident_payer_zip": fake.zipcode(),
                "auto_accident_policy_number": fake.ssn(),
                "auto_accident_return_to_work_date": fake.date_time_between(start_date=start_date, end_date=end_date).isoformat(),
                "auto_accident_significant_injury": fake.random_element(elements=('yes', 'no')),
                "auto_accident_significant_injury_notes": fake.text(),
                "auto_accident_similar_condition_date": fake.date_time_between(start_date=start_date, end_date=end_date).isoformat(),
                "auto_accident_similar_condition_notes": fake.text(),
                "auto_accident_state_of_occurrence": fake.state(),
                "auto_accident_still_under_care": fake.boolean(),
                "auto_accident_subscriber_address": fake.address(),
                "auto_accident_subscriber_city": fake.city(),
                "auto_accident_subscriber_date_of_birth": fake.date_time_between(start_date=start_date, end_date=end_date).isoformat(),
                "auto_accident_subscriber_first_name": fake.first_name(),
                "auto_accident_subscriber_last_name": fake.last_name(),
                "auto_accident_subscriber_middle_name": fake.first_name(),
                "auto_accident_subscriber_phone_number": fake.phone_number(),
                "auto_accident_subscriber_social_security": fake.ssn(),
                "auto_accident_subscriber_state": fake.state(),
                "auto_accident_subscriber_suffix": fake.suffix(),
                "auto_accident_subscriber_zip_code": fake.zipcode(),
                "auto_accident_treatment_duration": fake.random_element(elements=('30 days', '60 days', '90 days', '120 days', '180 days', 'other')),
                "auto_accident_will_require_therapy": fake.boolean(),
                "auto_accident_will_require_therapy_rec": fake.boolean()
                },
            "cell_phone": fake.phone_number(),
            "chart_id": fake.numerify(text='######'),
            "city": fake.city(),
            "copay": fake.numerify(text='##'),
            "custom_demographics": [
                {
                "field_type": fake.random_element(elements=('text', 'number', 'date', 'boolean')),
                "updated_at": fake.date_time_between(start_date=start_date, end_date=end_date).isoformat(),
                "value": fake.text(),
                }
            ],
            "date_of_birth": fake.date_time_between(start_date=dob_startdate, end_date=dob_enddate).isoformat(),
            "date_of_first_appointment": fake.date_time_between(start_date=appnt_firstdate, end_date=appnt_firstenddate).isoformat(),
            "date_of_last_appointment": fake.date_time_between(start_date=appnt_lastdate, end_date=appnt_lastenddate).isoformat(),
            "default_pharmacy": fake.company(),
            "disable_sms_messages": fake.boolean(),
            "doctor": fake.random_element(elements=doc_ids),
            "email": fake.email(),
            "emergency_contact_name": fake.name(),
            "emergency_contact_phone": fake.phone_number(),
            "emergency_contact_relation": fake.random_element(elements=('self', 'spouse', 'child', 'other')),
            "employer": fake.company(),
            "employer_address": fake.address(),
            "employer_city": fake.city(),
            "employer_state": fake.state(),
            "employer_zip_code": fake.zipcode(),
            "ethnicity": fake.random_element(elements=('hispanic', 'not_hispanic', 'unknown')),
            "first_name": fake.first_name(),
            "gender": fake.random_element(elements=('Male', 'Female', 'Queer', 'Transgender', 'Other')),
            "home_phone": fake.phone_number(),
            "id": fake.numerify(text='######'),
            "last_name": fake.last_name(),
            "middle_name": fake.first_name(),
            "nick_name": fake.first_name(),
            "office_phone": fake.phone_number(),
            "offices": [
                fake.numerify(text='######'),
            ],
            "patient_flags": [
                {
                "archived": fake.boolean(),
                "color": fake.color(),
                "created_at": fake.date_time_between(start_date=start_date, end_date=end_date).isoformat(),
                "doctor": fake.numerify(text='######'),
                "id": fake.numerify(text='######'),
                "name": fake.name(),
                "priority": fake.numerify(text='##'),
                "updated_at": fake.date_time_between(start_date=start_date, end_date=end_date).isoformat(),
                }
            ],
            "patient_flags_attached": [
                {
                "archived": fake.boolean(),
                "created_at": fake.date_time_between(start_date=start_date, end_date=end_date).isoformat(),
                "flag_text": fake.text(),
                "flag_type": fake.random_element(elements=('patient', 'appointment')),
                "id": fake.numerify(text='######'),
                "updated_at": "string"
                }
            ],
            "patient_payment_profile": fake.random_elements(elements=('cash', 'credit_card', 'insurance', 'other')),
            "patient_photo": fake.image_url(),
            "patient_photo_date": fake.date_time_between(start_date=start_date, end_date=end_date).isoformat(),
            "patient_status": fake.random_element(elements=('active', 'inactive', 'pending')),
            "preferred_language": fake.random_element(elements=('english', 'spanish', 'french', 'german', 'other')),
            "primary_care_physician": fake.numerify(text='######'),
            "primary_insurance": {
                "insurance_claim_office_number": fake.numerify(text='######'),
                "insurance_company": fake.company(),
                "insurance_group_name": fake.company(),
                "insurance_group_number": fake.numerify(text='######'),
                "insurance_id_number": fake.numerify(text='######'),
                "insurance_payer_id": fake.numerify(text='######'),
                "insurance_plan_name": fake.company(),
                "insurance_plan_type": fake.random_element(elements=('HMO', 'PPO', 'POS', 'EPO', 'other')),
                "is_subscriber_the_patient": fake.boolean(),
                "patient_relationship_to_subscriber": fake.random_element(elements=('self', 'spouse', 'child', 'other')),
                "photo_back": fake.image_url(),
                "photo_front": fake.image_url(),
                "subscriber_address": fake.address(),
                "subscriber_city": fake.city(),
                "subscriber_country": fake.country(),
                "subscriber_date_of_birth": fake.date_time_between(start_date=start_date, end_date=end_date).isoformat(),
                "subscriber_first_name": fake.first_name(),
                "subscriber_gender": fake.random_element(elements=('Male', 'Female', 'Transgender', 'Other')),
                "subscriber_last_name": fake.last_name(),
                "subscriber_middle_name": fake.first_name(),
                "subscriber_social_security": fake.ssn(),
                "subscriber_state": fake.state(),
                "subscriber_suffix": fake.suffix(),
                "subscriber_zip_code": fake.zipcode()
            },
            "race": fake.random_element(elements=('white', 'black', 'asian', 'hispanic', 'other')),
            "referring_doctor": {
                "address": fake.address(),
                "email": fake.email(),
                "fax": fake.phone_number(),
                "first_name": fake.first_name(),
                "last_name": fake.last_name(),
                "middle_name": fake.first_name(),
                "npi": fake.numerify(text='##########'),
                "phone": fake.phone_number(),
                "provider_number": fake.numerify(text='######'),
                "provider_qualifier": fake.random_element(elements=('MD', 'DO', 'PA', 'NP', 'other')),
                "specialty": fake.random_element(elements=('general_practice', 'internal_medicine', 'pediatrics', 'other')),
                "suffix": fake.suffix(),
            },
            "referring_source": fake.random_element(elements=('self', 'spouse', 'child', 'other')),
            "responsible_party_email": fake.email(),
            "responsible_party_name": fake.name(),
            "responsible_party_phone": fake.phone_number(),
            "responsible_party_relation": fake.random_element(elements=('self', 'spouse', 'child', 'other')),
            "secondary_insurance": {
                "insurance_claim_office_number": fake.phone_number(),
                "insurance_company": fake.company(),
                "insurance_group_name": fake.company(),
                "insurance_group_number": fake.numerify(text='######'),
                "insurance_id_number": fake.numerify(text='######'),
                "insurance_payer_id": fake.numerify(text='#########'),
                "insurance_plan_name": fake.company(),
                "insurance_plan_type": fake.random_element(elements=('HMO', 'PPO', 'POS', 'EPO', 'other')),
                "is_subscriber_the_patient": fake.boolean(),
                "patient_relationship_to_subscriber": fake.random_element(elements=('self', 'spouse', 'child', 'other')),
                "photo_back": fake.image_url(),
                "photo_front": fake.image_url(),
                "subscriber_address": fake.address(),
                "subscriber_city": fake.city(),
                "subscriber_country": fake.country(),
                "subscriber_date_of_birth": fake.date_time_between(start_date=start_date, end_date=end_date).isoformat(),
                "subscriber_first_name": fake.first_name(),
                "subscriber_gender": fake.random_element(elements=('Male', 'Female', 'Transgender', 'Queer', 'Other')),
                "subscriber_last_name": fake.last_name(),
                "subscriber_middle_name": fake.first_name(),
                "subscriber_social_security": fake.ssn(),
                "subscriber_state": fake.state(),
                "subscriber_suffix": fake.suffix(),
                "subscriber_zip_code": fake.zipcode()
            },
            "social_security_number": fake.ssn(),
            "state": fake.state(),
            "tertiary_insurance": {
                "insurance_claim_office_number": fake.phone_number(),
                "insurance_company": fake.company(),
                "insurance_group_name": fake.company(),
                "insurance_group_number": fake.numerify(text='#########'),
                "insurance_id_number": fake.numerify(text='#######'),
                "insurance_payer_id": fake.numerify(text='############'),
                "insurance_plan_name": fake.company(),
                "insurance_plan_type": fake.random_element(elements=('HMO', 'PPO', 'POS', 'EPO', 'other')),
                "is_subscriber_the_patient": fake.boolean(),
                "patient_relationship_to_subscriber": fake.random_element(elements=('self', 'spouse', 'child', 'other')),
                "photo_back": fake.image_url(),
                "photo_front": fake.image_url(),
                "subscriber_address": fake.address(),
                "subscriber_city": fake.city(),
                "subscriber_country": fake.country(),
                "subscriber_date_of_birth": fake.date_time_between(start_date=start_date, end_date=end_date).isoformat(),
                "subscriber_first_name": fake.first_name(),
                "subscriber_gender": fake.random_elements(elements=('Male', 'Female', 'Transgender', 'Queer', 'Other')),
                "subscriber_last_name": fake.last_name(),
                "subscriber_middle_name": fake.first_name(),
                "subscriber_social_security": fake.ssn(),
                "subscriber_state": fake.state(),
                "subscriber_suffix": fake.suffix(),
                "subscriber_zip_code": fake.zipcode()
            },
            "updated_at": fake.date_time_between(start_date=start_date, end_date=end_date).isoformat(),
            "workers_comp_insurance": {
                "property_and_casualty_agency_claim_number": fake.numerify(text='#########'),
                "workers_comp_carrier_code": fake.numerify(text='#########'),
                "workers_comp_case_number": fake.numerify(text='######'),
                "workers_comp_company": fake.company(),
                "workers_comp_date_of_accident": fake.date_time_between(start_date=start_date, end_date=end_date).isoformat(),
                "workers_comp_group_name": fake.company(),
                "workers_comp_group_number": fake.numerify(text='#########'),
                "workers_comp_notes": fake.text(),
                "workers_comp_payer_address": fake.address(),
                "workers_comp_payer_city": fake.city(),
                "workers_comp_payer_id": fake.numerify(text='#########'),
                "workers_comp_payer_state": fake.state(),
                "workers_comp_payer_zip": fake.zipcode(),
                "workers_comp_state_of_occurrence": fake.state(),
                "workers_comp_wcb": fake.numerify(text='#########'),
                "workers_comp_wcb_rating_code": fake.numerify(text='###')
            },
            "zip_code": fake.zipcode()
        }

        list_response.append(dictionaryResponse)

    return list_response

    


import requests

class DOCTORS():

    """
    https://app.drchrono.com/api-docs/#tag/Administrative/operation/doctors_list

    """

    def __init__(self, api_key, doctor_id=None):
        self.doctor_id = doctor_id
        assert isinstance(api_key, str), 'You must provide a valid API Key'
        self.api_key = api_key

    @property
    def doctorlist(self):
        path = 'https://app.drchrono.com/api/doctors'
        list_response = []

        while path:
            data = requests.get(path, headers={'Authorization': 'Bearer ' + self.api_key})
            data_json = data.json()
            list_response.extend(data_json['results'])
            path = data_json['next'] 
        
        return list_response
   
    def doctor_single(self, doctor_id):
        path = 'https://app.drchrono.com/api/doctors/{}'.format(doctor_id)
        try: 
            data = requests.get(path, headers={'Authorization': 'Bearer ' + self.api_key})
            data_json = data.json()
            return data_json
        except Exception as e:
            print(e)








from . import session

class MEDICATIONS(object):

    def __init__(self, medication_id=None, patient_id=None):
        self.medication_id = medication_id
        self.patient_id = patient_id

    @staticmethod
    def medicationlist_types():
        dictionaryResponse = {
            "data": [
                {
                "appointment": 0,
                "date_prescribed": "string",
                "date_started_taking": "string",
                "date_stopped_taking": "string",
                "daw": "true",
                "dispense_quantity": 0,
                "doctor": 0,
                "dosage_quantity": "string",
                "dosage_units": "string",
                "frequency": "string",
                "id": 0,
                "indication": "string",
                "name": "string",
                "ndc": "string",
                "notes": "string",
                "number_refills": 0,
                "order_status": "",
                "patient": 0,
                "pharmacy_note": "string",
                "prn": "true",
                "route": "string",
                "rxnorm": "string",
                "signature_note": "string",
                "status": "active"
                }
            ],
            "next": "string",
            "previous": "string"
        }

        return dictionaryResponse

    @staticmethod
    def medicationlist():
        path = 'https://app.drchrono.com/api/medications'
        list_response = []
        while path:
            data = session.get(path)
            data_json = data.json()
            list_response.extend(data_json['results'])
            path = data_json['next']
        return list_response

    @classmethod
    def medication_patient(cls, patient_id):
        path = "https://app.drchrono.com/api/medications?patient=" + patient_id 
        try: 
            data = session.get(path)
            data_json = data.json()
            return data_json
        except Exception as e:
            print(e)

    @classmethod
    def medication_single(cls, medication_id):
        path = 'https://app.drchrono.com/api/medications/{}'.format(medication_id)
        try: 
            data = session.get(path)
            data_json = data.json()
            return data_json
        except Exception as e:
            print(e)




import requests 

class DOCUMENTS():

    def __init__(self, api_key, date=None, description=None, doctor=None, document=None, patient=None, archieved=None, metatags=None):
        self.date = date
        self.description = description
        self.doctor = doctor
        self.document = document
        self.patient = patient
        self.archieved = archieved
        self.metatags = metatags
        assert isinstance(api_key, str), 'You must provide a valid API Key'
        self.api_key = api_key

    def create_document(self, date, description, doctor, document, patient, metatags):
        """
            Create a document
        """
        path = 'https://drchrono.com/api/documents'
        data = {
            'date':date,
            'description': description,
            'doctor': doctor,
            'patient': patient,
            'metatags': metatags,
        }
        file=document
        try:
            data = requests.post(path, data, files=file, headers={'Authorization': 'Bearer ' + self.api_key})
            data_json = data.json()
            return data_json

        except Exception as e:
            print(e)



from faker import Faker

def doctorlist_fake(fake_count):
    localeList = ['en-US']
    fake = Faker(localeList)
    list_response = []
    for i in range(fake_count):
        dictionaryResponse = {
            "cell_phone": fake.phone_number(),  
            "country": fake.random_element(elements=('US', 'MX', 'CA', 'BD', 'IN')), 
            "email": fake.email(), 
            "first_name": fake.first_name(), 
            "group_npi_number": fake.numerify(text='##########'),
            "home_phone": fake.phone_number(),
            "id": fake.numerify(text='######'),
            "is_account_suspended": fake.boolean(),
            "job_title": fake.random_element(elements=('Provider/Staff', 'Provider/Admin')),
            "last_name": fake.last_name(),
            "npi_number": fake.numerify(text='##########'),
            "office_phone": fake.phone_number(),
            "practice_group": fake.numerify(text='######'),
            "practice_group_name": fake.company(),
            "profile_picture": fake.image_url(),
            "specialty": fake.random_element(elements=('Psychiatrist', 'Psychologist', 'Caremanager', 'Nurse', 'Social Worker', 'Gastroenterologist', 'Dermatologist', 'Cardiologist', 'Neurologist', 'Oncologist', 'Ophthalmologist', 'Orthopedic Surgeon', 'Pediatrician', 'Family Physician', 'General Practitioner', 'Internist', 'Obstetrician/Gynecologist', 'Surgeon', 'Urologist', 'Endocrinologist', 'Infectious Disease Specialist', 'Nephrologist', 'Pulmonologist', 'Rheumatologist', 'Allergist/Immunologist', 'Anesthesiologist', 'Emergency Medicine Specialist', 'Hematologist/Oncologist', 'Neonatologist', 'Neurosurgeon', 'Radiologist', 'Sports Medicine Specialist', 'Vascular Surgeon', 'Other')),
            "suffix": fake.suffix(),
            "timezone": fake.random_element(elements=('US/Central', 'US/Western', 'US/Eastern', 'US/Mountain', 'US/Pacific', 'US/Alaska', 'US/Hawaii', 'US/Arizona', 'US/Indiana-Starke', 'US/Michigan', 'US/Pacific-New', 'US/Samoa')),
            "website": fake.url()
            }
        list_response.append(dictionaryResponse)
    return list_response


from . import session

class DOCTORS(object):

    """
    https://app.drchrono.com/api-docs/#tag/Administrative/operation/doctors_list

    """

    def __init__(self, doctor_id=None, fake_count=1):
        self.doctor_id = doctor_id
        self.fake_count = fake_count

    @staticmethod
    def doctorlist():
        path = 'https://app.drchrono.com/api/doctors'
        list_response = []

        while path:
            data = session.get(path)
            data_json = data.json()
            list_response.extend(data_json['results'])
            path = data_json['next'] 
        
        return list_response
            
    @classmethod
    def doctor_single(cls, doctor_id):
        path = 'https://app.drchrono.com/api/doctors/{}'.format(doctor_id)
        try: 
            data = session.get(path)
            data_json = data.json()
            return data_json
        except Exception as e:
            print(e)








import requests
class PATIENTS():

    def __init__(self, api_key, patient_id=None, fake_count=None, **kwargs):
        self.patient_id = patient_id
        self.fake_count = fake_count
        assert isinstance(api_key, str), 'You must provide a valid API Key'
        self.api_key = api_key

    @property
    def patientlist(self):
        print('Key sent: ', self.api_key)
        path = 'https://drchrono.com/api/patients'
        list_response = []
        while path:
            data = requests.get(path, headers={'Authorization': 'Bearer ' + self.api_key})
            data_json = data.json()
            list_response.extend(data_json['results'])
            path = data_json['next']
        return list_response

    def patient_single(self, patient_id):
        path = 'https://drchrono.com/api/patients/{}'.format(patient_id)
        print('path: ', path)
        try: 
            data = requests.get(path, headers={'Authorization': 'Bearer ' + self.api_key})
            data_json = data.json()
            return data_json
        except Exception as e:
            print(e)

    def patient_summary_read(self, patient_id):
        path = 'https://drchrono.com/api/patients_summary/{}'.format(patient_id)
        try: 
            data = requests.get(path, headers={'Authorization': 'Bearer ' + self.api_key})
            if data == 200:
                data_json = data.json()
                return data_json
            else:
                print('Error: {}'.format(data))
        except Exception as e:
            print(e)

    def patient_ccda(self, patient_id):
        path = 'https://drchrono.com/api/patients/{}/ccda'.format(patient_id)
        try: 
            data = requests.get(path, headers={'Authorization': 'Bearer ' + self.api_key})
            if data == 200:
                data_json = data.json()
                return data_json
            else:
                print('Error: {}'.format(data))
        except Exception as e:
            print(e)

    def patient_onpatient(self, patient_id):
        path = 'https://drchrono.com/api/patients/{}/onpatient_access'.format(patient_id)
        try: 
            data = requests.get(path, headers={'Authorization': 'Bearer ' + self.api_key})
            if data == 200:
                data_json = data.json()
                return data_json
            else:
                print('Error: {}'.format(data))
        except Exception as e:
            print(e)


import requests

class MEDICATIONS():

    def __init__(self, api_key, patient_id=None, medication_id=None, **kwargs):
        self.patient_id = patient_id
        self.medication_id = medication_id
        assert isinstance(api_key, str), 'You must provide a valid API Key'
        self.api_key = api_key

    @property
    def medicationlist(self):
        path = 'https://app.drchrono.com/api/medications'
        list_response = []
        while path:
            data = requests.get(path, headers={'Authorization': 'Bearer ' + self.api_key})
            data_json = data.json()
            list_response.extend(data_json['results'])
            path = data_json['next']
        return list_response

    def medication_patient(self, patient_id):
        path = "https://app.drchrono.com/api/medications?patient=" + patient_id 
        try: 
            data = requests.get(path, headers={'Authorization': 'Bearer ' + self.api_key})
            data_json = data.json()
            return data_json
        except Exception as e:
            print(e)

    def medication_single(self, medication_id):
        path = 'https://app.drchrono.com/api/medications/{}'.format(medication_id)
        try: 
            data = requests.get(path, headers={'Authorization': 'Bearer ' + self.api_key})
            data_json = data.json()
            return data_json
        except Exception as e:
            print(e)


from faker import Faker
import datetime
import random

def appointment_list_fake(fake_count, pt_ids, doc_ids):
    localeList = ['en-US']
    fake = Faker(localeList)
    list_response = []
    start_date = datetime.datetime.now() - datetime.timedelta(days=1095)
    end_date = datetime.datetime.now() + datetime.timedelta(days=30)
    for i in range(fake_count):
        dictionaryResponse = {
                "allow_overlapping": fake.boolean(),
                "appt_is_break": fake.boolean(),
                "base_recurring_appointment": fake.boolean(),
                "billing_notes": [
                    {
                    "appointment": fake.numerify(text='######'),
                    "created_at": fake.date_between(start_date, end_date).isoformat(),
                    "created_by": fake.numerify(text='######'),
                    "id": fake.numerify(text='######'),
                    "text": fake.paragraph(nb_sentences=5)
                    }
                ],
                "billing_provider": fake.numerify(text='######'),
                "billing_status": fake.random_element(elements=('No Show', 'Pain In Full', 'Cancelled', 'Balance Due')),
                "clinical_note": {
                    "locked": fake.boolean(),
                    "pdf": fake.boolean(),
                    "updated_at": fake.date_between(start_date, end_date).isoformat()
                },
                "cloned_from": fake.numerify(text='######'),
                "color": fake.random_element(elements=('#BFBFFF', '#FF7F05', '#9932CC', '#228B22')),
                "created_at": fake.date_between(start_date, end_date).isoformat(),
                "custom_fields": [
                    {
                    "created_at": fake.date_between(start_date, end_date).isoformat(),
                    "field_type": fake.random_element(elements=('category', 'date', 'dropdown', 'number', 'text')),
                    "field_value": fake.text(max_nb_chars=20),
                    "updated_at": fake.date_between(start_date, end_date).isoformat()
                    }
                ],
                "custom_vitals": [
                    {
                    "value": fake.numerify(text='##'),
                    "vital_type": fake.text(max_nb_chars=20)
                    }
                ],
                "deleted_flag": fake.boolean(),
                "doctor": random.choice(doc_ids),
                "duration": fake.random_element(elements=('15', '30', '45', '60', '90')),
                "exam_room": fake.numerify(text='######'),
                "extended_updated_at": fake.date_between(start_date, end_date).isoformat(),
                "first_billed_date": fake.date_between(start_date, end_date).isoformat(),
                "icd10_codes": 
                    [fake.random_element(elements=('A00', 'A01', 'A02', 'A03', 'A04', 'A05', 'A06', 'A07', 'A08', 'A09', 'A10', 'A11', 'A12', 'A13', 'A14', 'A15', 'A16', 'A17', 'A18', 'A19', 'A20', 'A21', 'A22', 'A23', 'A24', 'A25', 'A26', 'A27', 'A28', 'A29', 'A30', 'A31', 'A32', 'A33', 'A34', 'A35', 'A36', 'A37', 'A38', 'A39', 'A40', 'A41', 'A42', 'A43', 'A44', 'A45', 'A46', 'A47', 'A48', 'A49', 'A50', 'A51', 'A52', 'A53', 'A54', 'A55', 'A56', 'A57', 'A58', 'A59', 'A60', 'A61', 'A62', 'A63', 'A64', 'A65', 'A66', 'A67', 'A68', 'A69', 'A70', 'A71', 'A72', 'A73', 'A74', 'A75', 'A76', 'A77', 'A78', 'A79', 'A80', 'A81', 'A82', 'A83', 'A84', 'A85', 'A86', 'A87', 'A88', 'A89', 'A90', 'A91', 'A92', 'A93', 'A94', 'A95', 'A96', 'A97', 'A98', 'A99', 'B00', 'B01', 'B02', 'B03', 'B04', 'B05', 'B06', 'B07', 'B08', 'B09', 'B10', 'B11', 'B12', 'B13', 'B14', 'B15', 'B16', 
                    'B17', 'B18', 'B19', 'B20', 'B21', 'B22')) for i in range(random.randint(0,10))],
                "icd9_codes":
                    [fake.random_element(elements=('A00', 'A01', 'A02', 'A03', 'A04', 'A05', 'A06', 'A07', 'A08', 'A09', 'A10', 'A11', 'A12', 'A13', 'A14', 'A15', 'A16', 'A17', 'A18', 'A19', 'A20', 'A21', 'A22', 'A23', 'A24', 'A25', 'A26', 'A27', 'A28', 'A29', 'A30', 'A31', 'A32', 'A33', 'A34', 'A35', 'A36', 'A37', 'A38', 'A39', 'A40', 'A41', 'A42', 'A43', 'A44', 'A45', 'A46', 'A47', 'A48', 'A49', 'A50', 'A51', 'A52', 'A53', 'A54', 'A55', 'A56', 'A57', 'A58', 'A59', 'A60', 'A61', 'A62', 'A63', 'A64', 'A65', 'A66', 'A67', 'A68', 'A69', 'A70', 'A71', 'A72', 'A73', 'A74', 'A75', 'A76', 'A77', 'A78', 'A79', 'A80', 'A81', 'A82', 'A83', 'A84', 'A85', 'A86', 'A87', 'A88', 'A89', 'A90', 'A91', 'A92', 'A93', 'A94', 'A95', 'A96', 'A97', 'A98', 'A99', 'B00', 'B01', 'B02', 'B03', 'B04', 'B05', 'B06', 'B07', 'B08', 'B09', 'B10', 'B11', 'B12', 'B13', 'B14', 'B15', 'B16', 
                    'B17', 'B18', 'B19', 'B20', 'B21', 'B22')) for i in range(random.randint(0,10))],
                "id": fake.numerify(text='######'),
                "ins1_status": fake.random_element(elements=('Arrived', 'Checked In', 'Checked Out', 'No Show', 'Scheduled', 'Waiting')),
                "ins2_status": fake.random_element(elements=('Arrived', 'Checked In', 'Checked Out', 'No Show', 'Scheduled', 'Waiting')),
                "is_virtual_base": fake.boolean(),
                "is_walk_in": fake.boolean(),
                "last_billed_date": fake.date_between(start_date, end_date).isoformat(),
                "notes": fake.sentences(nb=10),
                "office": fake.numerify(text='######'),
                "patient": random.choice(pt_ids),
                "primary_insurance_id_number": fake.numerify(text='###########'),
                "primary_insurer_name": fake.company(),
                "primary_insurer_payer_id": fake.numerify(text='########'),
                "profile": fake.numerify(text='######'),
                "reason": fake.random_element(elements=('Pain', 'Sick', 'Other')),
                "recurring_appointment": fake.boolean(),
                "reminder_profile": fake.numerify(text='######'),
                "reminders": [
                    {
                    "id": fake.numerify(text='######'),
                    "scheduled_time": fake.date_between(start_date, end_date).isoformat(),
                    "type": fake.random_element(elements=('SMS', 'Email', 'Phone Call'))
                    }
                ],
                "scheduled_time": fake.date_between(start_date, end_date).isoformat(),
                "secondary_insurance_id_number": fake.pystr(),
                "secondary_insurer_name": fake.company(),
                "secondary_insurer_payer_id": fake.pystr(),
                "status": fake.random_element(elements=('Arrived', 'Checked In', 'Cancelled', 'Checked Out', 'No Show', 'Scheduled', 'Waiting')),
                "status_transitions": [
                    {
                    "appointment": fake.numerify(text='######'),
                    "datetime": fake.date_between(start_date, end_date).isoformat(),
                    "from_status": fake.random_element(elements=('Arrived', 'Checked In', 'Cancelled', 'Checked Out', 'No Show', 'Scheduled', 'Waiting')),
                    "to_status": fake.random_element(elements=('Arrived', 'Checked In', 'Cancelled', 'Checked Out', 'No Show', 'Scheduled', 'Waiting'))
                    }
                ],
                "supervising_provider": fake.numerify(text='######'),
                "vitals": {
                    "blood_pressure_1": fake.numerify(text='###'),
                    "blood_pressure_2": fake.numerify(text='##'),
                    "bmi": fake.numerify(text='##'),
                    "head_circumference": fake.numerify(text='##'),
                    "head_circumference_units": fake.random_element(elements=('cm', 'in')),
                    "height": fake.numerify(text='##'),
                    "height_units": fake.random_element(elements=('cm', 'in')),
                    "oxygen_saturation": fake.numerify(text='##'),
                    "pain": fake.random_element(elements=('None', 'Mild', 'Moderate', 'Severe')),
                    "pulse": fake.numerify(text='##'),
                    "respiratory_rate": fake.numerify(text='##'),
                    "smoking_status": fake.random_element(elements=('Current', 'Former', 'Never', 'Unknown')),
                    "temperature": fake.numerify(text='##'),
                    "temperature_units": fake.random_element(elements=('C', 'F')),
                    "weight": fake.numerify(text='##'),
                    "weight_units": fake.random_element(elements=('kg', 'lb'))
                },
                "updated_at": fake.date_between(start_date, end_date).isoformat()
        }
        
        list_response.append(dictionaryResponse)

    return list_response


DRC_VERSION = (0, 0, 8)

PATIENTS_API_VERSION = (0, 0, 8)
APPOINTMENTS_API_VERSION = (0, 0, 8)
DOCUMENTS_API_VERSION = (0, 0, 8)
MEDICATIONS_API_VERSION = (0, 0, 8)

USERS_API_VERSION = (0, 0, 8)
DOCTORS_API_VERSION = (0, 0, 8)




from .admin_doctors import *
from .admin_users import *
from .clinical_appointments import *
from .clinical_patients import *

class faker(object):

    def __init__(self, fakecount_adminuser=None, fakecount_admindocs=None, fakecount_clin_patients=None, fakecount_clin_appt=None, **kwargs):
        self.fakecount_adminuser = fakecount_adminuser
        self.fakecount_admindocs = fakecount_admindocs
        self.fakecount_clin_patients = fakecount_clin_patients
        self.fakecount_clin_appt = fakecount_clin_appt

    @classmethod
    def generate(cls, fakecount_adminuser=None, fakecount_admindocs=None, fakecount_clin_patients=None, fakecount_clin_appt=None):
        
        adm_users = userlist_fake(fakecount_adminuser)
        adm_docs = doctorlist_fake(fakecount_admindocs)

        # get a unique list of id's from docs dictionary
        doc_ids = []
        for i in adm_docs:
            doc_ids.append(i['id'])
        
        clin_pts = patientlist_fake(fakecount_clin_patients, doc_ids)

        pt_ids = []
        for i in clin_pts:
            pt_ids.append(i['id'])        
            
        clin_appts = appointment_list_fake(fakecount_clin_appt, pt_ids, doc_ids)

        return adm_users, adm_docs, clin_pts, clin_appts



from setuptools import setup, find_packages

setup(
    name='drchrono',
    version='0.0.8',
    license='MIT',
    author="Hants Williams",
    author_email='hantsawilliams@gmail.com',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    url='https://github.com/hantswilliams/drchrono-wrapper',
    keywords='drchrono api wrapper',
    install_requires=[
          'requests',
          'faker',
          'python-dotenv'
      ],

)




from . import constants

from .clinical import appointments, documents, medications, patients
from .admin import doctors, users
from .fake import faker

"""
documentation section: https://app.drchrono.com/api-docs/#section/Introduction 
"""

class drc:

    """
    Entry point class providing ad-hoc API clients for each drChrono API.
    """

    def __init__(self, api_key=None):
        ## if api_key is None, display warning message
        assert api_key is not None, 'API Key must be set for real data retrieval'
        self.api_key = api_key

    @property
    def version(self):
        """
        Returns the current version of the Drchrono API wrapper library
        :returns: `tuple`
        """
        return constants.DRC_VERSION

    @property
    def version_patients(self):
        """
        Returns the current version of the Drchrono API wrapper library
        :returns: `tuple`
        """
        return constants.PATIENTS_API_VERSION

    ##### clinical section #####
    ##### clinical section #####
    ##### clinical section #####
    ##### clinical section #####

    def appointments(self):
        """
        Gives a `drc.patient_manager.appointments` instance that can be used to read/write data from the
        patient API.
        """
        return appointments.APPOINTMENTS(self.api_key)

    def documents(self):
        """
        Gives a `drc.patient_manager.documents` instance that can be used to read/write data from the
        patient API.
        """
        return documents.DOCUMENTS(self.api_key)

    def medications(self):
        """
        Gives a `drc.patient_manager.medications` instance that can be used to read/write data from the
        patient API.
        """
        return medications.MEDICATIONS(self.api_key)

    def patients(self):
        """
        Gives a `drc.patient_manager.patients` instance that can be used to read/write data from the
        patient API.
        """
        return patients.PATIENTS(self.api_key)

    ##### admin section ######
    ##### admin section ######
    ##### admin section ######
    ##### admin section ######

    def doctors(self):
        """
        Gives a `drc.admin.doctors` instance that can be used to read/write data from the
        patient API.
        """
        return doctors.DOCTORS(self.api_key)

    def users(self):
        """
        Gives a `drc.admin.users` instance that can be used to read/write data from the
        patient API.
        """
        return users.USERS(self.api_key)

    ##### fake section ######
    ##### fake section ######
    ##### fake section ######
    ##### fake section ######

    def faker():
        """
        Gives a `drc.fake.faker` instance that can be used to read/write data from the
        patient API.
        """
        return faker.faker()











import requests

class USERS():

    def __init__(self, api_key, user_id=None, group_id=None, fake_count=1):
        self.user_id = user_id
        self.group_id = group_id
        self.fake_count = fake_count
        assert isinstance(api_key, str), 'You must provide a valid API Key'
        self.api_key = api_key

    @property
    def userlist(self):
        path = 'https://app.drchrono.com/api/users'
        list_response = []
        while path:
            data = requests.get(path, headers={'Authorization': 'Bearer ' + self.api_key})
            data_json = data.json()
            list_response.extend(data_json['results'])
            path = data_json['next']
        return list_response

    @property
    def usergrouplist(self):
        path = 'https://app.drchrono.com/api/user_groups'
        list_response = []
        while path:
            data = requests.get(path, headers={'Authorization': 'Bearer ' + self.api_key})
            data_json = data.json()
            list_response.extend(data_json['results'])
            path = data_json['next']
        return list_response

    def user_single(self, user_id):
        path = 'https://app.drchrono.com/api/users/{}'.format(user_id)
        try: 
            data = requests.get(path, headers={'Authorization': 'Bearer ' + self.api_key})
            data_json = data.json()
            return data_json
        except Exception as e:
            print(e)

    def usergrouplist_single(self, group_id):
        path = 'https://app.drchrono.com/api/user_groups/{}'.format(group_id)
        try: 
            data = requests.get(path, headers={'Authorization': 'Bearer ' + self.api_key})
            data_json = data.json()
            return data_json
        except Exception as e:
            print(e)






from faker import Faker

def userlist_fake(fake_count):
    localeList = ['en-US']
    fake = Faker(localeList)
    list_response = []
    for i in range(fake_count):
        dictionaryResponse = {
            "doctor": fake.numerify(text='######'),
            "id": fake.numerify(text='######'),
            "is_doctor": fake.boolean(),
            "is_staff": fake.boolean(),
            "permissions": {
                'share_patients': fake.boolean(),
                'access_all_messages_for_practice_group': fake.boolean(),
                'show_patient_balance': fake.boolean(),
                'access_to_erx': fake.boolean(),
                'access_patient_payments': fake.boolean(),
                'emergency_access': fake.boolean(),
                'access_patient_analytics': fake.boolean(),
                'provider_dropdown': fake.boolean(),
                'create_and_update_patients': fake.boolean(),
                'appointment_provider_selection': fake.boolean(),
                'manage_templates': fake.boolean(),
                'access_to_message_center': fake.boolean(),
                'show_billing_summary': fake.boolean(),
                'access_patient_statements': fake.boolean(),
                'access_reports': fake.boolean(),
                'manage_accounts': fake.boolean(),
                'manage_permissions': fake.boolean(),
                'drug_interactions_check': fake.boolean(),
                'sign/lock_clinical_notes': fake.boolean(),
                'access_billing': fake.boolean(),
                'access_clinical_notes': fake.boolean(),
                'billing_administrator': fake.boolean(),
                'access_institutional_billing': fake.boolean(),
                'add_new_referring_sources': fake.boolean(),
                'export_patients': fake.boolean(),
                'use_ipad_ehr': fake.boolean(),
                'settings': fake.boolean(),
                'access_balance/ledger': fake.boolean(),
                'access_scheduling': fake.boolean(),
                'show_billing_tab': fake.boolean(),
                'create_and_update_contacts': fake.boolean(),
                'view_practice_group': fake.boolean()
            },
            "practice_group": fake.numerify(text='######'),
            "username": (fake.name()).replace(" ", "")
        }
        list_response.append(dictionaryResponse)
    return list_response


from . import session

class PATIENTS(object):

    def __init__(self, patient_id=None, fake_count=None, **kwargs):
        self.patient_id = patient_id
        self.fake_count = fake_count

    @staticmethod
    def patientlist():
        path = 'https://drchrono.com/api/patients'
        list_response = []
        while path:
            data = session.get(path)
            data_json = data.json()
            list_response.extend(data_json['results'])
            path = data_json['next']
        return list_response

    @classmethod
    def patient_single(cls, patient_id):
        path = 'https://drchrono.com/api/patients/{}'.format(patient_id)
        print('path: ', path)
        try: 
            data = session.get(path)
            if data == 200:
                data_json = data.json()
                return data_json
            else:
                print('Error: {}'.format(data))
        except Exception as e:
            print(e)

    @classmethod
    def patient_summary_read(cls, patient_id):
        path = 'https://drchrono.com/api/patients_summary/{}'.format(patient_id)
        try: 
            data = session.get(path)
            if data == 200:
                data_json = data.json()
                return data_json
            else:
                print('Error: {}'.format(data))
        except Exception as e:
            print(e)

    @classmethod
    def patient_ccda(cls, patient_id):
        path = 'https://drchrono.com/api/patients/{}/ccda'.format(patient_id)
        try: 
            data = session.get(path)
            if data == 200:
                data_json = data.json()
                return data_json
            else:
                print('Error: {}'.format(data))
        except Exception as e:
            print(e)

    @classmethod
    def patient_onpatient(cls, patient_id):
        path = 'https://drchrono.com/api/patients/{}/onpatient_access'.format(patient_id)
        try: 
            data = session.get(path)
            if data == 200:
                data_json = data.json()
                return data_json
            else:
                print('Error: {}'.format(data))
        except Exception as e:
            print(e)